# frozen_string_literal: true

describe WPScan::DB::Version do
  describe '#vulnerabilities' do
    # Handled in spec/app/models/wp_version_spec
  end
end
